@@ -22,7 +22,7 @@ LOGGING_CONFIG = {
         },
     },
     "loggers": {
-        "csc-recorder": {
+        "root": {
             "handlers": ["development"],
             "level": "DEBUG",
             "propagate": False,
